@@ -1,11 +1,17 @@
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#ifdef HAVE_STRING_H
+#include <string.h>
+#endif
+
+#include <string>
+#include <cstring>
+
 #include "pluginmanager.h"
 #include "file.hpp"
-#include <string>
-
-
-#include <string.h>
-
-
+#include "iappdirs.h"
 
 StarDictPluginBaseObject::StarDictPluginBaseObject(const char *filename, GModule *module_, plugin_configure_func_t configure_func_):
 	plugin_filename(filename), module(module_), configure_func(configure_func_)
@@ -44,7 +50,9 @@ const char *StarDictPluginBase::get_filename()
 	return baseobj->plugin_filename.c_str();
 }
 
-StarDictPlugins::StarDictPlugins(const char *dirpath, const std::list<std::string>& order_list, const std::list<std::string>& disable_list)
+StarDictPlugins::StarDictPlugins(const std::string& dirpath,
+	const std::list<std::string>& order_list,
+	const std::list<std::string>& disable_list)
 {
 	plugindirpath = dirpath;
 	load(dirpath, order_list, disable_list);
@@ -65,7 +73,7 @@ private:
 	StarDictPlugins& plugins;
 };
 
-void StarDictPlugins::load(const char *dirpath, const std::list<std::string>& order_list, const std::list<std::string>& disable_list)
+void StarDictPlugins::load(const std::string& dirpath, const std::list<std::string>& order_list, const std::list<std::string>& disable_list)
 {
 	std::list<std::string> plugins_dirs;
 	plugins_dirs.push_back(dirpath);
@@ -179,7 +187,7 @@ void StarDictPlugins::get_plugin_list(const std::list<std::string>& order_list,
 	}
 }
 
-typedef bool (*stardict_plugin_init_func_t)(StarDictPlugInObject *obj);
+typedef bool (*stardict_plugin_init_func_t)(StarDictPlugInObject *obj, IAppDirs* appDirs);
 
 void StarDictPlugins::get_plugin_info(const char *filename, StarDictPlugInType &plugin_type, std::string &info_xml, bool &can_configure)
 {
@@ -200,7 +208,7 @@ void StarDictPlugins::get_plugin_info(const char *filename, StarDictPlugInType &
 		return;
 	}
 	StarDictPlugInObject *plugin_obj = new StarDictPlugInObject();
-	bool failed = func.stardict_plugin_init(plugin_obj);
+	bool failed = func.stardict_plugin_init(plugin_obj, app_dirs);
 	if (failed) {
 		g_print("Load %s failed!\n", filename);
 		g_module_close (module);
@@ -250,7 +258,7 @@ void StarDictPlugins::load_plugin(const char *filename)
 		return;
 	}
 	StarDictPlugInObject *plugin_obj = new StarDictPlugInObject();
-	bool failed = func.stardict_plugin_init(plugin_obj);
+	bool failed = func.stardict_plugin_init(plugin_obj, app_dirs);
 	if (failed) {
 		g_print("Load %s failed!\n", filename);
 		g_module_close (module);
@@ -267,7 +275,7 @@ void StarDictPlugins::load_plugin(const char *filename)
 		} func2;
 		func2.stardict_virtualdict_plugin_init = 0;
 		if (!g_module_symbol (module, "stardict_virtualdict_plugin_init", (gpointer *)&(func2.stardict_virtualdict_plugin_init_avoid_warning))) {
-			printf("Load %s failed: No stardict_virtualdict_plugin_init func!\n", filename);
+			g_print("Load %s failed: No stardict_virtualdict_plugin_init func!\n", filename);
 			g_module_close (module);
 			delete baseobj;
 			return;
@@ -289,7 +297,7 @@ void StarDictPlugins::load_plugin(const char *filename)
 		} func2;
 		func2.stardict_netdict_plugin_init = 0;
 		if (!g_module_symbol (module, "stardict_netdict_plugin_init", (gpointer *)&(func2.stardict_netdict_plugin_init_avoid_warning))) {
-			printf("Load %s failed: No stardict_netdict_plugin_init func!\n", filename);
+			g_print("Load %s failed: No stardict_netdict_plugin_init func!\n", filename);
 			g_module_close (module);
 			delete baseobj;
 			return;
@@ -311,7 +319,7 @@ void StarDictPlugins::load_plugin(const char *filename)
 		} func2;
 		func2.stardict_specialdict_plugin_init = 0;
 		if (!g_module_symbol (module, "stardict_specialdict_plugin_init", (gpointer *)&(func2.stardict_specialdict_plugin_init_avoid_warning))) {
-			printf("Load %s failed: No stardict_specialdict_plugin_init func!\n", filename);
+			g_print("Load %s failed: No stardict_specialdict_plugin_init func!\n", filename);
 			g_module_close (module);
 			delete baseobj;
 			return;
@@ -333,7 +341,7 @@ void StarDictPlugins::load_plugin(const char *filename)
 		} func2;
 		func2.stardict_tts_plugin_init = 0;
 		if (!g_module_symbol (module, "stardict_tts_plugin_init", (gpointer *)&(func2.stardict_tts_plugin_init_avoid_warning))) {
-			printf("Load %s failed: No stardict_tts_plugin_init func!\n", filename);
+			g_print("Load %s failed: No stardict_tts_plugin_init func!\n", filename);
 			g_module_close (module);
 			delete baseobj;
 			return;
@@ -355,7 +363,7 @@ void StarDictPlugins::load_plugin(const char *filename)
 		} func3;
 		func3.stardict_parsedata_plugin_init = 0;
 		if (!g_module_symbol (module, "stardict_parsedata_plugin_init", (gpointer *)&(func3.stardict_parsedata_plugin_init_avoid_warning))) {
-			printf("Load %s failed: No stardict_parsedata_plugin_init func!\n", filename);
+			g_print("Load %s failed: No stardict_parsedata_plugin_init func!\n", filename);
 			g_module_close (module);
 			delete baseobj;
 			return;
@@ -377,7 +385,7 @@ void StarDictPlugins::load_plugin(const char *filename)
 		} func4;
 		func4.stardict_misc_plugin_init = 0;
 		if (!g_module_symbol (module, "stardict_misc_plugin_init", (gpointer *)&(func4.stardict_misc_plugin_init_avoid_warning))) {
-			printf("Load %s failed: No stardict_misc_plugin_init func!\n", filename);
+			g_print("Load %s failed: No stardict_misc_plugin_init func!\n", filename);
 			g_module_close (module);
 			delete baseobj;
 			return;
@@ -391,7 +399,7 @@ void StarDictPlugins::load_plugin(const char *filename)
 		}
 		MiscPlugins.add(baseobj);
 	} else {
-		g_print("Load %s failed: Unknow type plugin!\n", filename);
+		g_print("Load %s failed: Unknown type plugin!\n", filename);
 		g_module_close (module);
 		delete baseobj;
 		return;
@@ -601,6 +609,11 @@ const char *StarDictNetDictPlugins::dict_name(size_t iPlugin)
 	return oPlugins[iPlugin]->dict_name();
 }
 
+const char *StarDictNetDictPlugins::dict_link(size_t iPlugin)
+{
+	return oPlugins[iPlugin]->dict_link();
+}
+
 const char *StarDictNetDictPlugins::dict_id(size_t iPlugin)
 {
 	return oPlugins[iPlugin]->get_filename();
@@ -647,6 +660,11 @@ const char *StarDictNetDictPlugin::dict_name()
 	return obj->dict_name;
 }
 
+const char *StarDictNetDictPlugin::dict_link()
+{
+	return obj->dict_link;
+}
+
 const char *StarDictNetDictPlugin::dict_cacheid()
 {
 	return obj->dict_cacheid;
