@@ -11,11 +11,10 @@
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Library General Public License for more details.
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -25,14 +24,16 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 
-#include "sockets.hpp"
-#include "md5.h"
-#include "getuint32.h"
-
-#include "stardict_client.hpp"
-
+#include <cstring>
+#include <cstdio>
+#include <cstdlib>
 #include <stdlib.h>
 #include <stdio.h>
+#include "sockets.hpp"
+#include "md5.h"
+#include "utils.h"
+
+#include "stardict_client.hpp"
 
 #define PROTOCOL_VERSION "0.3"
 
@@ -868,9 +869,9 @@ int StarDictClient::parse_banner(gchar *line)
     status = atoi(line);
     if (status != CODE_HELLO) {
         if (status == CODE_TEMPORARILY_UNAVAILABLE) {
-            printf("Server temporarily unavailable!\n");
+            g_print("Server temporarily unavailable!\n");
         } else {
-            printf("Unexpected status code %d\n", status);
+            g_print("Unexpected status code %d\n", status);
         }
         return 0;
     }
