@@ -8,7 +8,7 @@ const int SELECTION_INTERVAL=300; 		    // check selection interval.
 
 class Selection {
 private:
-    gint IsBusy;
+	gint IsBusy;
 	gint timeout;
 
 	void create_selection_widget();
@@ -23,8 +23,10 @@ public:
 	GtkWidget* selection_widget;
 
 	Selection();
-	void Start();
-    void End();
+	void Init();
+	void End();
+	void start();
+	void stop();
 };
 
 #endif
